=======
History
=======

v0.5.0 (2020-03-11)
------------------

* Package made public (published via zenodo.org)
* Package still under development


v0.4.0 (2020-03-11)
------------------

* Package reorganised (code cleanup, multi thread engine added)

v0.3.0 (2020-02-06)
------------------

* Package reorganised (better output, examples included)

v0.2.0 (2020-02-02)
------------------

* Package renamed to OpenQTSim

v0.1.0 (2019-06-09)
------------------

* First version developed by Joris den Uijl
